MeonKYC class
MeonKYC Widget - A comprehensive KYC solution for Flutter
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MeonKYC
Constructors
-
MeonKYC({Key? key, required String companyName, String workflow = 'individual', OnSuccessCallback? onSuccess, OnErrorCallback? onError, OnCloseCallback? onClose, Map<
String, dynamic> ? customStyles, bool enableIPV = true, bool enablePayments = true, bool autoRequestPermissions = true, bool showHeader = true, String headerTitle = 'KYC Process', String baseURL = 'https://live.meon.co.in'}) -
const
Properties
- autoRequestPermissions → bool
-
Auto-request permissions when needed
final
- baseURL → String
-
Base URL for the KYC service
final
- companyName → String
-
Company name (required)
final
-
customStyles
→ Map<
String, dynamic> ? -
Custom styles for the widget
final
- enableIPV → bool
-
Enable IPV (In-Person Verification) features
final
- enablePayments → bool
-
Enable payment link handling
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerTitle → String
-
Header title text
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → OnCloseCallback?
-
Close callback
final
- onError → OnErrorCallback?
-
Error callback
final
- onSuccess → OnSuccessCallback?
-
Success callback
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHeader → bool
-
Show header bar
final
- workflow → String
-
Workflow type (default: 'individual')
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MeonKYC> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited